@@ -1,7 +1,7 @@
 use v5.14.0;
 use warnings;
 
-package JMAP::Tester 0.104;
+package JMAP::Tester 0.105;
 # ABSTRACT: a JMAP client made for testing JMAP servers
 
 use Moo;
@@ -520,9 +520,9 @@ sub upload {
 
 #pod =method download
 #pod
-#pod   my $result = $tester->download(\%arg);
+#pod   my $result = $tester->download(\%uri_arg, \%other_arg);
 #pod
-#pod Valid arguments are:
+#pod The first hashref provides values that go into the download URI:
 #pod
 #pod   blobId    - the blob to download (no default)
 #pod   accountId - the account for which we're downloading (no default)
@@ -533,6 +533,13 @@ sub upload {
 #pod placeholder but no argument for that is given to C<download>, an exception
 #pod will be thrown.
 #pod
+#pod The second hashref, which is optional, provides other arguments to the method.
+#pod Right now, there is only one, B<which will go away>.  The argument is only here
+#pod for legacy purposes, specifically for the Cyrus IMAP project, and may be
+#pod removed B<at any time>.
+#pod
+#pod   accept    - the value of the Accept header to use when downloading
+#pod
 #pod The return value will either be a L<failure
 #pod object|JMAP::Tester::Result::Failure> or an L<upload
 #pod result|JMAP::Tester::Result::Download>.
@@ -604,14 +611,15 @@ sub download_uri_for {
 }
 
 sub download {
-  my ($self, $arg) = @_;
+  my ($self, $uri_arg, $arg) = @_;
 
-  my $uri = $self->download_uri_for($arg);
+  my $uri = $self->download_uri_for($uri_arg);
 
   my $get = HTTP::Request->new(
     GET => $uri,
     [
       $self->_maybe_auth_header,
+      ($arg->{accept} ? (Accept => $arg->{accept}) : ()),
     ],
   );
 
@@ -775,22 +783,22 @@ sub simple_auth {
   return $self->should_return_futures ? $future : $future->$Failsafe->get;
 }
 
-#pod =method update_client_session
+#pod =method get_client_session
 #pod
-#pod   $tester->update_client_session;
-#pod   $tester->update_client_session($auth_uri);
+#pod   $tester->get_client_session;
+#pod   $tester->get_client_session($auth_uri);
 #pod
-#pod This method fetches the content at the authentication endpoint and uses it to
-#pod configure the tester's target URIs and signing keys.
+#pod This method fetches the content at the authentication endpoint.
 #pod
 #pod This method respects the C<should_return_futures> attributes of the
 #pod JMAP::Tester object, and in futures mode will return a future that will resolve
-#pod to the Result.
+#pod to the L<JMAP::Tester::Result::Auth> object.
 #pod
 #pod =cut
 
-sub update_client_session {
+sub _get_client_session_future {
   my ($self, $auth_uri) = @_;
+
   $auth_uri //= $self->authentication_uri;
 
   my $auth_req = HTTP::Request->new(
@@ -820,7 +828,37 @@ sub update_client_session {
       client_session  => $client_session,
     });
 
-    $self->configure_from_client_session($client_session);
+    return Future->done($auth);
+  });
+}
+
+sub get_client_session {
+  my ($self, $auth_uri) = @_;
+  my $future = $self->_get_client_session_future($auth_uri);
+  return $self->should_return_futures ? $future : $future->$Failsafe->get;
+}
+
+#pod =method update_client_session
+#pod
+#pod   $tester->update_client_session;
+#pod   $tester->update_client_session($auth_uri);
+#pod
+#pod This method fetches the content at the authentication endpoint and uses it to
+#pod configure the tester's target URIs and signing keys.
+#pod
+#pod This method respects the C<should_return_futures> attributes of the
+#pod JMAP::Tester object, and in futures mode will return a future that will resolve
+#pod to the Result.
+#pod
+#pod =cut
+
+sub update_client_session {
+  my ($self, $auth_uri) = @_;
+
+  my $future = $self->_get_client_session_future($auth_uri)->then(sub {
+    my ($auth) = @_;
+
+    $self->configure_from_client_session($auth->client_session);
 
     return Future->done($auth);
   });
@@ -1013,7 +1051,7 @@ JMAP::Tester - a JMAP client made for testing JMAP servers
 
 =head1 VERSION
 
-version 0.104
+version 0.105
 
 =head1 OVERVIEW
 
@@ -1184,9 +1222,9 @@ to the Result.
 
 =head2 download
 
-  my $result = $tester->download(\%arg);
+  my $result = $tester->download(\%uri_arg, \%other_arg);
 
-Valid arguments are:
+The first hashref provides values that go into the download URI:
 
   blobId    - the blob to download (no default)
   accountId - the account for which we're downloading (no default)
@@ -1197,6 +1235,13 @@ If the download URI template has a C<blobId>, C<accountId>, or C<type>
 placeholder but no argument for that is given to C<download>, an exception
 will be thrown.
 
+The second hashref, which is optional, provides other arguments to the method.
+Right now, there is only one, B<which will go away>.  The argument is only here
+for legacy purposes, specifically for the Cyrus IMAP project, and may be
+removed B<at any time>.
+
+  accept    - the value of the Accept header to use when downloading
+
 The return value will either be a L<failure
 object|JMAP::Tester::Result::Failure> or an L<upload
 result|JMAP::Tester::Result::Download>.
@@ -1213,6 +1258,17 @@ This method respects the C<should_return_futures> attributes of the
 JMAP::Tester object, and in futures mode will return a future that will resolve
 to the Result.
 
+=head2 get_client_session
+
+  $tester->get_client_session;
+  $tester->get_client_session($auth_uri);
+
+This method fetches the content at the authentication endpoint.
+
+This method respects the C<should_return_futures> attributes of the
+JMAP::Tester object, and in futures mode will return a future that will resolve
+to the L<JMAP::Tester::Result::Auth> object.
+
 =head2 update_client_session
 
   $tester->update_client_session;
